@@ -26,7 +26,7 @@ class Finding:
     def __str__(self):
         return f"""
 ## [{self.severity}-{self.number}] {self.title}
-{self.description}
+{self.description}\n
 """
 
     def get_summary_title(self) -> str:
@@ -43,3 +43,16 @@ class Finding:
         summary_title = re.sub(r"\s+", "-", summary_title)
         summary_title = re.sub(r"[^a-z0-9-_]", "", summary_title)
         return f"#{summary_title}"
+
+    def fix_markdown_headers(self):
+        """Formats the markdown headers to be in-line with the format of this document.
+
+        For example, if the markdown headers are:
+        # Impact
+        asdfasdfs
+
+        We will adjust it to:
+        ### Impact
+        """
+        self.description = re.sub(r"^# ", "### ", self.description, flags=re.M)
+        self.description = re.sub(r"^## ", "### ", self.description, flags=re.M)
